Learn R Programming

rgeos (version 0.3-19)

Ring-class: Class "Ring"

Description

class for linear ring

Arguments

Objects from the Class

Objects can be created by calls to the function Ring

Slots

coords:
Object of class "matrix"; coordinates of the ring; first point should equal the last point
ID:
Object of class "character"; unique identifier string

Methods

Methods defined with class "Ring" in the signature:
bbox
signature(obj = "Ring"): retrieves the bbox element
coordinates
signature(object = "Ring"): retrieves the coords element from Ring objects in rings slot
coordnames
signature(object = "Ring"): retrieves coordinate names
coerce
signature(from = "Ring", to = "SpatialPoints"): ...

See Also

Ring

Examples

Run this code
	#NONE 

Run the code above in your browser using DataLab