gpc.poly.nohole-class: Class "gpc.poly.nohole"
Description
A class for representing polygons with multiple contours but without
holes.
Objects from the Class
Objects can be created by calls of the form
new("gpc.poly.nohole", ...) or by calling read.polyfile.Slots
- pts
- Object of class list. See the help for
gpc.poly for details.
Extends
Class gpc.poly, directly.Methods
- coerce
signature(from = "numeric", to = "gpc.poly.nohole"): ...